# GALINDA
Group 11's PyPI Package, CodeAstro 2025

GALINDA is a Galaxy Image N-Body Data Animator. Galinda is designed to provide you with 2D Histogram images of particles in your simulations and produce an animation of these histograms. This function is useful for obtaining a quick overall view of your simulated astronomical object and its evolution over time-steps.

Inputs: A folder containing HDF5 files of particle position data for a given snapshot or time-step. 

Package Requirements: numpy, matplotlib, h5py, ffmpeg

Any comments, questions, or concerns, please reach out to the developers: emmadavis818@.gmail.edu, pfofie@uci.edu, edward.skrabacz@u.northwestern.edu
